<?php

/**
 * Plugin Name: Lightroom Classic Photo List Generator
 * Description: A plugin to extract photo references from text and generate a list compatible with Lightroom Classic. Paste [lightroom_classic_display_text_form] in any page to display the tool.
 * Version: 1.0
 * Author: aSeed Fred Lefeuvre
 */



// Function to display the text input form and the result, including usage instructions

function display_lightroom_classic_text_form() {

    ?>

    <div class="lightroom-classic-photo-list-generator">

        <h2>Lightroom Classic Photo List Generator</h2>
        <form id="photo-list-form" method="post" action="">

            <textarea name="lightroom-classic-photo-list-generator-text" id="lightroom-classic-photo-list-generator-text" placeholder="Paste your text here, it can be also excel cells, file path..."></textarea>
            <button type="submit">Generate list</button>

        </form>
		<p><small>This tool is provided by <a href="https://photo.aseed.fr">aSeed</a> to save hours of your photographer's life.</small></p>
        <?php

        if (isset($_POST['lightroom-classic-photo-list-generator-text'])) {

            $text = $_POST['lightroom-classic-photo-list-generator-text'];

            $references = extract_lightroom_classic_photo_references($text);

            if (!empty($references)) {

                $list_of_references = implode(", ", $references);

                echo "<h3>Result:</h3>";

                echo "<textarea id='photo-list' readonly>{$list_of_references}</textarea>";

                echo "<button onclick='copyPhotoList()'>Copy List</button>";

            } else {

                echo "<p>No photo references found.</p>";

            }

        }

        ?>

    </div>

    <script>

        function copyPhotoList() {

            var photoList = document.getElementById('photo-list');

            photoList.select();

            document.execCommand('copy');

            alert('Photo list copied to clipboard / You can paste it to your Lightroom Library');

        }

    </script>

    <?php

}



// Function to extract photo references from the text
function extract_lightroom_classic_photo_references($text) {
    $references = [];
    $regex = "/(?:\b\w{0,}_\d{4}\b|\b\d{4}\b|\(\d+\))/";
    if (preg_match_all($regex, $text, $matches)) {
        $references = array_unique($matches[0]);
    }
    return $references;
}


// Add a shortcode to display the text input form along with usage instructions

function lightroom_classic_text_form_shortcode() {

    ob_start();

    display_lightroom_classic_text_form();

    return ob_get_clean();

}

add_shortcode('lightroom_classic_display_text_form', 'lightroom_classic_text_form_shortcode');

